# The applet http://mathlets.org/mathlets/beta-distribution/
# allows you to look at density graphs for many beta distributions.
# The goal of this studio is to relate the beta distribution to others
# that you know.
# We'll start with a function like the mathlet which will plot 
# the beta density in R:
studioBeta = function(a,b){ # the two arguments a and b are the "shape
  # parameters" for the distribution.
  x=seq(0,1,.01) # this is a hundred points from 0 to 1, where each beta lives
  mean=a/(a+b) # this is the mean of beta(a,b), from Wikipedia
  variance=a*b/((a+b+1)*(a+b)*(a+b)) # same for variance
  # You might notice that
  # variance = mean*(1-mean)/(a+b+1)
  # See why that's true?
  sigma=sqrt(variance) # this is how you get standard deviation from variance
  beta=dbeta(x,a,b) # this is how R computes the density function for beta(a,b)
  # at the values of x. We could have written
  # beta = factorial(a+b-1)/(factorial(a-1)*factorial(b-1))*x^(a-1)*(1-x)^(b-1)
  # Try it; move the #'s!
 betaplottitle=paste("Beta distn, a =",a,", b =",b) # this makes a string for the title
 betasubtitle=paste("mean =",format(mean,digits=4),"variance =",format(variance,digits=4))
 plot(x,beta,type="l",ylab = "density",xlab = "", sub =betasubtitle,
       main = betaplottitle)
  # you could make little circles instead of a line by changing type from "l"
  # (which stands for "line") to "p" (which stands for "point")
 norm=dnorm(x,mean,sigma)
 lines(x,norm,col="red",type="l")
}
# Once you've run these lines (so "studioBeta" appears on your list of Functions
# in the Environment window) try typing "studioBeta(4,5)" and other values
# to see what these curves look like. Bigger a and b are more bell-shaped.

# Here's a function that does the same thing for the binomial distribution
# with parameters N and p. But the distribution has been RESCALED by
# dividing by N. The result is that instead of taking values from 0 to N, 
# it takes values from 0 to 1. Just like beta!

studioBinomial = function(N,p){
  x=seq(0,1,1/N) # these are the N+1 values of the scaled distribution
  mean=p # the mean was N*p before we divided by N: reason is that the 
  # binomial is the sum of N Bernoulli's, each with mean p
  variance=p*(1-p)/N # variance before scaling was N*p*(1-p)
  # You might notice that
  # variance = mean*(1-mean)/N
  # See why that's true?
  sigma=sqrt(variance)
 binomialplottitle=paste("Binomial N =",N,", p =",p)
 binomialsubtitle=paste("mean =",format(mean,digits=4),"variance =",format(variance,digits=4))
  binom=dbinom(N*x,N,p)*N # dbinom is the probability of N*x. We could have
  # written instead
  # binom= choose(N,N*x)*p^(N*x)*(1-p)^(N*(1-x))
  # try it!
  plot(x,binom,type="s",ylab="density",xlab="", col="blue",
       main=binomialplottitle,sub = binomialsubtitle)
}

# I'll put in a couple of test runs just so you can source the whole
# file and something will happen:
studioBeta(7,13)
studioBinomial(20,.35)
# Notice anything about these two plots? If you do, you're ready
# to work on the questions.